// java wrapper for vtkIdTypeArray object
//

package vtk;
import vtk.*;

public class vtkIdTypeArray extends vtkDataArray
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native int GetDataType_2();
  public int GetDataType()
    { return GetDataType_2(); }

  private native int GetValue_3(int id0);
  public int GetValue(int id0)
    { return GetValue_3(id0); }

  private native void SetValue_4(int id0,int id1);
  public void SetValue(int id0,int id1)
    { SetValue_4(id0,id1); }

  private native void SetNumberOfValues_5(int id0);
  public void SetNumberOfValues(int id0)
    { SetNumberOfValues_5(id0); }

  private native void InsertValue_6(int id0,int id1);
  public void InsertValue(int id0,int id1)
    { InsertValue_6(id0,id1); }

  private native int InsertNextValue_7(int id0);
  public int InsertNextValue(int id0)
    { return InsertNextValue_7(id0); }

  private native long FastDownCast_8(vtkAbstractArray id0);
  public vtkIdTypeArray FastDownCast(vtkAbstractArray id0) {
    long temp = FastDownCast_8(id0);

    if (temp == 0) return null;
    return (vtkIdTypeArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native int GetDataTypeValueMin_9();
  public int GetDataTypeValueMin()
    { return GetDataTypeValueMin_9(); }

  private native int GetDataTypeValueMax_10();
  public int GetDataTypeValueMax()
    { return GetDataTypeValueMax_10(); }

  public vtkIdTypeArray() { super(); }

  public vtkIdTypeArray(long id) { super(id); }
  public native long   VTKInit();

}
